@@ -83,10 +83,11 @@ class Policy(object):
 
     def set(self, tablename, method, **attributes):
         method = method.upper()
-        if not method in self.model or any(
-            key not in self.model[method] for key in attributes
-        ):
-            raise InvalidFormat("Invalid policy format")
+        if not method in self.model:
+            raise InvalidFormat("Invalid policy method: %s" % method)
+        invalid_keys = [key for key in attributes if key not in self.model[method]]
+        if invalid_keys:
+            raise InvalidFormat("Invalid keys: %s" % ",".join(invalid_keys))
         if not tablename in self.info:
             self.info[tablename] = copy.deepcopy(self.model)
         self.info[tablename][method].update(attributes)
@@ -249,8 +250,6 @@ class RestAPI(object):
             if fieldnames and not fieldname in fieldnames:
                 continue
             field = table[fieldname]
-            if not field.readable and not field.writable:
-                continue
             item = {"name": field.name, "label": field.label}
             # https://github.com/collection-json/extensions/blob/master/template-validation.md
             item["default"] = (
@@ -379,7 +378,7 @@ class RestAPI(object):
                     "le",
                     "startswith",
                     "contains",
-                    "in"
+                    "in",
                 ):
                     key_parts.append("eq")
                 is_negated = key_parts[0] == "not"
@@ -434,10 +433,17 @@ class RestAPI(object):
             queries.append(table)
 
         query = functools.reduce(lambda a, b: a & b, queries)
-        tfields = [table[tfieldname] for tfieldname in tfieldnames]
+        tfields = [table[tfieldname] for tfieldname in tfieldnames if
+                   table[tfieldname].type != 'password']
+        passwords = [tfieldname for tfieldname in tfieldnames if
+                     table[tfieldname].type == 'password']
         rows = db(query).select(
             *tfields, limitby=(offset, limit + offset), orderby=orderby
         )
+        if passwords:
+            dpass = {password: '******' for password in passwords}
+            for row in rows:
+                row.update(dpass)
 
         lookup_map = {}
         for key in list(lookup.keys()):
@@ -456,7 +462,8 @@ class RestAPI(object):
                 tfieldnames = filter_fieldnames(ref_table, tfieldnames)
                 check_table_lookup_permission(ref_tablename)
                 ids = [row[key] for row in rows]
-                tfields = [ref_table[tfieldname] for tfieldname in tfieldnames]
+                tfields = [ref_table[tfieldname] for tfieldname in tfieldnames if
+                           ref_table[tfieldname].type == 'password']
                 if not "id" in tfieldnames:
                     tfields.append(ref_table["id"])
                 drows = db(ref_table._id.belongs(ids)).select(*tfields).as_dict()
@@ -541,11 +548,11 @@ class RestAPI(object):
             response["items"] = rows.as_list()
         else:
             if table._format:
-                response["items"] = [dict(value=row.id, text=(
-                    table._format % row)) for row in rows]
+                response["items"] = [
+                    dict(value=row.id, text=(table._format % row)) for row in rows
+                ]
             else:
-                response["items"] = [dict(value=row.id, text=row.id)
-                    for row in rows]
+                response["items"] = [dict(value=row.id, text=row.id) for row in rows]
         if offset == 0:
             response["count"] = db(query).count()
         if model:
